@@ -1,4 +1,8 @@
 from typing import Any, Dict
+import jsonpickle
+from pydantic import BaseModel, Field
+
+
 
 def default_input_parser(*args, **kwargs):
     def serialize(args, kwargs):
@@ -38,27 +42,40 @@ def method_input_parser(*args, **kwargs):
 def default_output_parser(output, *args, **kwargs):
     return {"output": getattr(output, "content", output), "tokensUsage": None}
 
+class PydanticHandler(jsonpickle.handlers.BaseHandler):
+    def flatten(self, obj, data):
+        """Convert Pydantic model to a JSON-friendly dict using model_dump_json()"""
+        return jsonpickle.loads(obj.model_dump_json(), safe=True)
 
 PARAMS_TO_CAPTURE = [
   "frequency_penalty",
-  "function_call",
+  "function_call", 
   "functions",
   "logit_bias",
   "logprobs",
   "max_tokens",
+  "max_completion_tokens",
   "n",
-  "presence_penalty",
+  "presence_penalty", 
   "response_format",
   "seed",
   "stop",
+  "stream",
+  "audio",
+  "modalities",
   "temperature",
   "tool_choice",
   "tools",
+  "tool_calls",
+  "top_p",
+  "top_k",
   "top_logprobs",
-  "top_p",        
+  "prediction",
+  "service_tier",
+  "parallel_tool_calls",
   # Additional params
   "extra_headers",
-  "extra_query",
+  "extra_query", 
   "extra_body",
   "timeout"
 ]
